pub struct Error {
pub kind: ErrorKind,
pub(crate) span: Option<Span>,
}Fields
kind: ErrorKindspan: Option<Span>Implementations
Sourceimpl Error
impl Error
Sourcepub fn with_span(self, span: Span) -> Self
pub fn with_span(self, span: Span) -> Self
Adds a [struct Span] to this Error, if there isn’t already a more specific one.
pub fn kind(&self) -> &ErrorKind
Sourcepub fn StackUnderflow() -> Self
pub fn StackUnderflow() -> Self
Underflowed the stack
Sourcepub fn StackOverflow(place: usize) -> Self
pub fn StackOverflow(place: usize) -> Self
Overflowed the stack
Sourcepub fn NotIterable() -> Self
pub fn NotIterable() -> Self
In clause of For loop didn’t yield a Range
Sourcepub fn NotIndexable() -> Self
pub fn NotIndexable() -> Self
A value could not be indexed
Sourcepub fn NotDefined(name: Symbol) -> Self
pub fn NotDefined(name: Symbol) -> Self
A name was not defined in scope before being used
Sourcepub fn NotInitialized(name: Symbol) -> Self
pub fn NotInitialized(name: Symbol) -> Self
A name was defined but not initialized
Sourcepub fn NotCallable(value: ConValue) -> Self
pub fn NotCallable(value: ConValue) -> Self
A value was called, but is not callable
Sourcepub fn ArgNumber(want: usize, got: usize) -> Self
pub fn ArgNumber(want: usize, got: usize) -> Self
A function was called with the wrong number of arguments
Sourcepub fn MatchNonexhaustive(value: ConValue) -> Self
pub fn MatchNonexhaustive(value: ConValue) -> Self
Fell through a non-exhaustive match
Sourcepub fn BuiltinError(msg: impl ToString) -> Self
pub fn BuiltinError(msg: impl ToString) -> Self
Error produced by a Builtin